==> react-form-builder-1.12.0.tgz: package/lib/TextArea/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import React, { useCallback } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeTextAreaField from '@s-ui/react-molecule-textarea-field';

var TextArea = function TextArea(_ref) {
  var textArea = _ref.textArea,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors;
  var errorMessages = errors[textArea.id];
  var onChangeCallback = useCallback(function (evt) {
    return onChange(textArea.id, evt.target.value);
  }, [onChange, textArea]);
  var nextProps = {}; // transform constraints to props

  var constraints = textArea.constraints || [];
  nextProps = constraints.reduce(function (acc, constraint) {
    var _constraint$property, _constraint$property2, _constraint$property3, _constraint$property4, _constraint$property5, _constraint$property6, _constraint$property7;

    return _extends({}, acc, {}, (constraint == null ? void 0 : (_constraint$property = constraint.property) == null ? void 0 : _constraint$property.maxlength) && {
      maxChars: constraint == null ? void 0 : (_constraint$property2 = constraint.property) == null ? void 0 : _constraint$property2.maxlength
    }, {}, (constraint == null ? void 0 : (_constraint$property3 = constraint.property) == null ? void 0 : _constraint$property3.maxlength) && {
      maxLength: constraint == null ? void 0 : (_constraint$property4 = constraint.property) == null ? void 0 : _constraint$property4.maxlength
    }, {}, (constraint == null ? void 0 : (_constraint$property5 = constraint.property) == null ? void 0 : _constraint$property5.minlength) && {
      minLength: constraint == null ? void 0 : (_constraint$property6 = constraint.property) == null ? void 0 : _constraint$property6.minlength
    }, {}, (constraint == null ? void 0 : (_constraint$property7 = constraint.property) == null ? void 0 : _constraint$property7.notnull) === '' && {
      required: true
    });
  }, nextProps);
  nextProps = _extends({}, nextProps, {}, textArea.hidden && {
    hidden: true
  }, {}, textArea.disabled && {
    disabled: true
  }, {}, !!errorMessages && {
    errorText: errorMessages.join('\n')
  });

  var textAreaProps = _extends({
    placeholder: textArea.hint,
    id: textArea.id,
    name: textArea.id,
    label: textArea.label || '',
    tabIndex: tabIndex,
    value: textArea.value || '',
    onChange: onChangeCallback
  }, nextProps);

  if (nextProps.hidden) {
    return null;
  }

  return React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-TextArea sui-FormBuilder-" + textAreaProps.id
  }, React.createElement(MoleculeTextAreaField, Object.assign({}, textAreaProps, {
    textCharacters: "caracteres",
    size: "long"
  })));
};

TextArea.displayName = 'TextArea';
export default React.memo(TextArea, createComponentMemo('textArea'));

==> react-form-builder-1.14.0.tgz: package/lib/TextArea/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import React, { useCallback } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeTextAreaField from '@s-ui/react-molecule-textarea-field';

var TextArea = function TextArea(_ref) {
  var textArea = _ref.textArea,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      errors = _ref.errors;
  var errorMessages = errors[textArea.id];
  var onChangeCallback = useCallback(function (evt) {
    return onChange(textArea.id, evt.target.value);
  }, [onChange, textArea]);

  var onBlurCallback = function onBlurCallback() {
    return onBlur(textArea.id);
  };

  var nextProps = {}; // transform constraints to props

  var constraints = textArea.constraints || [];
  nextProps = constraints.reduce(function (acc, constraint) {
    var _constraint$property, _constraint$property2, _constraint$property3, _constraint$property4, _constraint$property5, _constraint$property6, _constraint$property7;

    return _extends({}, acc, {}, (constraint == null ? void 0 : (_constraint$property = constraint.property) == null ? void 0 : _constraint$property.maxlength) && {
      maxChars: constraint == null ? void 0 : (_constraint$property2 = constraint.property) == null ? void 0 : _constraint$property2.maxlength
    }, {}, (constraint == null ? void 0 : (_constraint$property3 = constraint.property) == null ? void 0 : _constraint$property3.maxlength) && {
      maxLength: constraint == null ? void 0 : (_constraint$property4 = constraint.property) == null ? void 0 : _constraint$property4.maxlength
    }, {}, (constraint == null ? void 0 : (_constraint$property5 = constraint.property) == null ? void 0 : _constraint$property5.minlength) && {
      minLength: constraint == null ? void 0 : (_constraint$property6 = constraint.property) == null ? void 0 : _constraint$property6.minlength
    }, {}, (constraint == null ? void 0 : (_constraint$property7 = constraint.property) == null ? void 0 : _constraint$property7.notnull) === '' && {
      required: true
    });
  }, nextProps);
  nextProps = _extends({}, nextProps, {}, textArea.hidden && {
    hidden: true
  }, {}, textArea.disabled && {
    disabled: true
  }, {}, !!errorMessages && {
    errorText: errorMessages.join('\n')
  });

  var textAreaProps = _extends({
    placeholder: textArea.hint,
    id: textArea.id,
    name: textArea.id,
    label: textArea.label || '',
    tabIndex: tabIndex,
    value: textArea.value || '',
    onChange: onChangeCallback,
    onBlur: onBlurCallback
  }, nextProps);

  if (nextProps.hidden) {
    return null;
  }

  return React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-TextArea sui-FormBuilder-" + textAreaProps.id
  }, React.createElement(MoleculeTextAreaField, Object.assign({}, textAreaProps, {
    textCharacters: "caracteres",
    size: "long"
  })));
};

TextArea.displayName = 'TextArea';
export default React.memo(TextArea, createComponentMemo('textArea'));
